Темы оформления в Pyrone

# Настраиваемые стили в Pyrone

Теперь в Pyrone можно иметь собственные стили для блога. Для этого вы должно создать собственный CSS-файл на основе стандартного blog.css, загрузить его во встроенное файловое хранилище, а затем выбрать этот файл/стиль на странице настроек сайта.

Есть несколько важных моментов, о которых вы должны знать: во-первых, CSS-файл ДОЛЖЕН иметь специально сформатированный заголовок, обычно он выглядит как-то так:

    /* pyrone-theme-css */
    /* pyrone-theme-data:title-en: Style name in english*/
    /* pyrone-theme-data:title-ru: Название стиля in russian*/

В первой строке обязательно должен находиться текст `/* pyrone-theme-css */` и только он, без такой строчки Pyrone не распознает этот CSS-файл как валидную тему оформления. Также в комментариях файла могут находиться другие метаданные, например, `/* pyrone-theme-data:title-en: Default style (template)*/`, эта строчка содержит данные, которые используются для отображения темы на странице настроек, для каждого языка своя строчка, если эти метаданные не добавлять, то в качестве названия темы будет использовано имя файла.

Второй важный момент — при закачке файла в хранилище ОБЯЗАТЕЛЬНО нужно выставить в поле Тип доступа к файлу значение пусть браузер сам решает, что делать, иначе Pyrone этот CSS-файл проигнорирует. Ну и, конечно, файл должен иметь расширение em>.css.

Вы можете ссылаться из CSS-файла на сторонние ресурсы, в том числе на загруженные в хранилище файла, например, картинки. Для этого используйте абсолютный путь вида `/files/f/image.png`, здесь image.png — это название загруженного в хранилище файла; вот пример:

    .account-twitter {
        background-repeat: no-repeat;
        background-position: top left;
        background-image: url(/files/f/twitter-icon.png);
        padding-left: 17px;
    }